"use strict";
/**
 * Serverless - Preview
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Preview = void 0;
const config_1 = require("../../config/config");
const getAllContentfulData_1 = require("../../utils/getAllContentfulData/getAllContentfulData");
const utils_1 = require("../../utils/utils");
const Render_1 = require("../../render/Render");
/**
 * Function - output preview from contentful
 *
 * @param {import('./PreviewTypes').PreviewArgs} args
 * @return {Promise<Response>} Response
 */
const Preview = async ({ request, next, siteConfig }) => {
    /* Params */
    const { searchParams } = new URL(request.url);
    const contentType = searchParams.get('content_type');
    const id = searchParams.get('preview');
    /* Preview id and content type required */
    if (!(0, utils_1.isStringStrict)(id) || !(0, utils_1.isStringStrict)(contentType)) {
        return next();
    }
    /* Config */
    (0, config_1.setConfig)(siteConfig);
    (0, utils_1.setFilters)(siteConfig.filters);
    (0, utils_1.setActions)(siteConfig.actions);
    (0, utils_1.setShortcodes)(siteConfig.shortcodes);
    config_1.config.env.dev = true;
    config_1.config.env.prod = false;
    /* Data params */
    const previewData = { id, contentType };
    /* Output */
    const data = await (0, Render_1.Render)({
        previewData,
        allData: await (0, getAllContentfulData_1.getAllContentfulData)({
            previewData
        })
    });
    let html = '';
    if ((0, utils_1.isObjectStrict)(data)) {
        html = data.output !== undefined ? data.output : '';
    }
    return new Response(html, {
        status: 200,
        headers: {
            'Content-Type': 'text/html;charset=UTF-8'
        }
    });
};
exports.Preview = Preview;
