"use strict";
/**
 * Utils - Get Prop
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProp = void 0;
const config_1 = require("../../config/config");
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const isNumber_1 = require("../isNumber/isNumber");
const isArray_1 = require("../isArray/isArray");
const dataSource_1 = require("../dataSource/dataSource");
/**
 * Easier access to id, renderType, contentType, fields, file and tag info
 *
 * @type {import('./getPropTypes').Prop}
 */
const getProp = {
    id(obj) {
        if (!(0, isObject_1.isObjectStrict)(obj)) {
            return '';
        }
        if (dataSource_1.dataSource.isContentful()) {
            return (0, isString_1.isStringStrict)(obj.sys?.id) ? obj.sys.id : '';
        }
        return (0, isString_1.isStringStrict)(obj.id) ? obj.id : '';
    },
    type(obj, subtype = 'render') {
        if (!(0, isObject_1.isObjectStrict)(obj)) {
            return '';
        }
        let type = '';
        if (dataSource_1.dataSource.isContentful()) {
            if ((0, isString_1.isStringStrict)(obj.sys?.contentType?.sys?.id)) {
                type = obj.sys.contentType.sys.id;
            }
            if ((0, isString_1.isStringStrict)(obj?.sys?.type) && type === '') {
                type = obj.sys.type;
            }
        }
        else {
            const key = subtype === 'render' ? 'renderType' : 'contentType';
            const value = obj[key];
            if ((0, isString_1.isStringStrict)(value)) {
                type = value;
            }
        }
        if (subtype === 'render' && (0, isString_1.isStringStrict)(config_1.config.renderTypes[type])) {
            type = config_1.config.renderTypes[type];
        }
        return type;
    },
    self(obj) {
        if (!(0, isObject_1.isObjectStrict)(obj)) {
            return obj;
        }
        if (dataSource_1.dataSource.isContentful()) {
            const key = 'fields';
            const fields = obj[key];
            return fields;
        }
        return obj;
    },
    fields(obj, prop) {
        if (!(0, isObject_1.isObjectStrict)(obj)) {
            return;
        }
        if (dataSource_1.dataSource.isContentful()) {
            const key = 'fields';
            const fields = obj[key];
            if (!(0, isObject_1.isObjectStrict)(fields)) {
                return;
            }
            return fields[prop];
        }
        return obj[prop];
    },
    file(obj, prop = 'url', source) {
        const res = {
            url: '',
            path: '',
            name: '',
            type: '',
            format: '',
            alt: '',
            naturalWidth: 0,
            naturalHeight: 0,
            size: 0
        };
        const fallback = prop === 'url' || prop === 'type' ? '' : undefined;
        if (!(0, isObject_1.isObjectStrict)(obj)) {
            return fallback;
        }
        if (dataSource_1.dataSource.isContentful(source)) {
            const fields = obj.fields;
            const file = obj.fields?.file;
            if (fields === undefined || file === undefined) {
                return fallback;
            }
            if ((0, isString_1.isStringStrict)(file.url)) {
                const url = `https:${file.url}`;
                res.url = url;
                if (prop === 'url') {
                    return url;
                }
            }
            if ((0, isString_1.isStringStrict)(file.contentType)) {
                const type = file.contentType;
                res.type = file.contentType;
                if (prop === 'type') {
                    return type;
                }
                res.format = type.split('/')[1];
            }
            res.alt = (0, isString_1.isStringStrict)(fields.description) ? fields.description : '';
            res.name = (0, isString_1.isStringStrict)(file.fileName) ? file.fileName : '';
            res.naturalWidth = (0, isNumber_1.isNumber)(file.details?.image?.width) ? file.details.image.width : 0;
            res.naturalHeight = (0, isNumber_1.isNumber)(file.details?.image?.height) ? file.details.image.height : 0;
            res.size = (0, isNumber_1.isNumber)(file.details?.size) ? file.details.size : 0;
        }
        else {
            const { path = '', name = '', type = '', format = 'jpg', width = 0, height = 0, size = 0 } = obj;
            if ((0, isString_1.isStringStrict)(path)) {
                const url = `${config_1.config.image.url}${path}`;
                res.url = url;
                if (prop === 'url') {
                    return `${url}.${format}`;
                }
            }
            if ((0, isString_1.isStringStrict)(type)) {
                res.type = type;
                if (prop === 'type') {
                    return type;
                }
            }
            res.path = path;
            res.name = name;
            res.format = format;
            res.naturalWidth = width;
            res.naturalHeight = height;
            res.size = size;
        }
        if (prop === 'all' && res.url !== '') {
            res.format = res.format === 'jpeg' ? 'jpg' : res.format;
            return res;
        }
        return fallback;
    },
    tag(obj, id) {
        if (!(0, isObject_1.isObjectStrict)(obj) || !(0, isString_1.isStringStrict)(id)) {
            return;
        }
        const tags = obj.metadata?.tags;
        if (!(0, isArray_1.isArrayStrict)(tags)) {
            return;
        }
        const tagInfo = {
            id: '',
            name: ''
        };
        tags.find((t) => {
            if (!(0, isObject_1.isObjectStrict)(t)) {
                return false;
            }
            const tagObj = dataSource_1.dataSource.isContentful() ? t.sys : t;
            if (!(0, isObject_1.isObjectStrict)(tagObj)) {
                return false;
            }
            const tagId = tagObj.id;
            if (tagId === id) {
                tagInfo.id = tagId;
                tagInfo.name = (0, isString_1.isStringStrict)(tagObj.name) ? tagObj.name : '';
                return true;
            }
            return false;
        });
        return tagInfo;
    }
};
exports.getProp = getProp;
