"use strict";
/**
 * Utils - Get Slug
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSlug = void 0;
const config_1 = require("../../config/config");
const getArchiveId_1 = require("../getArchiveId/getArchiveId");
const isObject_1 = require("../isObject/isObject");
/**
 * Function - recurse to get ascendents
 *
 * @private
 * @param {string} id
 * @param {import('../../global/globalTypes').SlugParent[]} p
 * @return {void}
 */
const _getParentSlug = (id = '', p = []) => {
    if (config_1.config.slug.parents[id] !== undefined && id !== '') {
        p.unshift(config_1.config.slug.parents[id]);
        _getParentSlug(config_1.config.slug.parents[id].id, p);
    }
};
/**
 * Function - get slug with base from slug base and parents
 *
 * @param {import('./getSlugTypes').SlugArgs} args
 * @return {string|import('./getSlugTypes').SlugReturn}
 */
const getSlug = (args) => {
    const { id = '', slug = '', page = 0, contentType = 'page', linkContentType = 'default', returnParents = false } = (0, isObject_1.isObjectStrict)(args) ? args : {};
    /* Index */
    if (slug === 'index') {
        return '';
    }
    /* Archive id */
    const archiveId = (0, getArchiveId_1.getArchiveId)(contentType, linkContentType);
    /* Slug base */
    const slugBase = config_1.config.slug.bases[contentType];
    let slugBaseSlug = '';
    let slugBaseOutput = '';
    if ((0, isObject_1.isObjectStrict)(slugBase)) {
        slugBaseSlug = slugBase.slug;
        if (slugBaseSlug === 'archive' && archiveId !== '') {
            slugBaseSlug = config_1.config.slug.archives[archiveId].slug;
        }
        slugBaseOutput = `${slugBaseSlug}${slugBaseSlug !== '' ? '/' : ''}`;
    }
    /* Parents */
    let p = [];
    let pp = [];
    _getParentSlug(contentType === 'page' ? id : archiveId, p);
    if (p.length > 0) {
        pp = p;
        p = `${p.map((item) => item.slug).join('/')}/`;
    }
    else {
        p = '';
    }
    /* Slug */
    const s = `${p}${slugBaseOutput}${slug}${page !== 0 ? `/?page=${page}` : ''}`;
    /* Parents and slug return */
    if (returnParents) {
        if (slugBaseSlug !== '' && archiveId !== '') {
            pp.unshift({
                ...slugBase,
                contentType: 'page',
                id: archiveId
            });
        }
        return {
            slug: s,
            parents: pp
        };
    }
    /* Slug return */
    return s;
};
exports.getSlug = getSlug;
