"use strict";
/**
 * Utils - Write Serverless Files
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeServerlessFiles = void 0;
/* Imports */
const promises_1 = require("node:fs/promises");
const node_path_1 = require("node:path");
const getPathDepth_1 = require("../getPathDepth/getPathDepth");
const config_1 = require("../../config/config");
/**
 * Function - write files from serverless
 *
 * @return {Promise<void>}
 */
const writeServerlessFiles = async () => {
    try {
        const formationPackage = `@alanizcreative/static-site-formation/${config_1.config.serverless.import}/serverless/`;
        /* Serverless folder */
        if (config_1.config.serverless.dir !== '') {
            await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir), { recursive: true });
        }
        /* Ajax file */
        if (config_1.config.serverless.files.ajax !== '') {
            const content = `import config from '${(0, getPathDepth_1.getPathDepth)(`${config_1.config.serverless.dir}/${config_1.config.serverless.files.ajax}`)}src/config'\nimport ajax from '${formationPackage}ajax'\nconst render = async ({ request, env }) => { return await ajax({ request, env, siteConfig: config }) }\nexport const onRequestPost = [render]\n`;
            const path = (0, node_path_1.resolve)(config_1.config.serverless.dir, config_1.config.serverless.files.ajax);
            const dir = (0, node_path_1.dirname)(path);
            await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir, dir), { recursive: true });
            await (0, promises_1.writeFile)(path, content);
            console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
        }
        /* Preview file */
        if (config_1.config.env.dev && config_1.config.serverless.files.preview !== '') {
            const content = `import config from '${(0, getPathDepth_1.getPathDepth)(`${config_1.config.serverless.dir}/${config_1.config.serverless.files.preview}`)}src/config'\nimport preview from '${formationPackage}preview'\nconst render = async ({ request, next }) => { return await preview({ request, next, siteConfig: config }) }\nexport const onRequestGet = [render]\n`;
            const path = (0, node_path_1.resolve)(config_1.config.serverless.dir, config_1.config.serverless.files.preview);
            const dir = (0, node_path_1.dirname)(path);
            await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir, dir), { recursive: true });
            await (0, promises_1.writeFile)(path, content);
            console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
        }
        /* Routes */
        const routes = Object.keys(config_1.config.serverless.routes);
        if (routes.length > 0) {
            const reloadFile = config_1.config.serverless.files.reload;
            for (let i = 0; i < routes.length; i += 1) {
                const type = routes[i];
                const routesArr = config_1.config.serverless.routes[type];
                for (let r = 0; r < routesArr.length; r += 1) {
                    let { path = '', content = '' } = routesArr[r];
                    if (type === 'reload' && reloadFile !== '' && path !== '') {
                        path = `${path}/${reloadFile}`;
                        content = `import config from '${(0, getPathDepth_1.getPathDepth)(`${config_1.config.serverless.dir}/${path}`)}src/config'\nimport reload from '${formationPackage}reload'\nconst render = async ({ request, env, next }) => { return await reload({ request, env, next, siteConfig: config }) }\nexport const onRequestGet = [render]\n`;
                    }
                    if (path !== '' && content !== '') {
                        path = (0, node_path_1.resolve)(config_1.config.serverless.dir, path);
                        const dir = (0, node_path_1.dirname)(path);
                        await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir, dir), { recursive: true });
                        await (0, promises_1.writeFile)(path, content);
                        console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
                    }
                }
            }
        }
    }
    catch (error) {
        console.error(config_1.config.console.red, '[SSF] Error writing serverless files: ', error);
    }
};
exports.writeServerlessFiles = writeServerlessFiles;
